@@ -1,6 +1,5 @@
 use std::fs::File;
 use std::io::{Read, Write};
-use std::os::unix::fs::PermissionsExt;
 use std::path::Path;
 
 use serde::{Deserialize, Serialize};
@@ -19,10 +18,12 @@ pub struct KeyFile {
 impl KeyFile {
     pub fn write_to_file(&self, path: &Path) {
         let mut file = File::create(path).expect("Failed to create / write a key file.");
-        let mut perm =
-            file.metadata().expect("Failed to retrieve key file metadata.").permissions();
-        perm.set_mode(u32::from(libc::S_IWUSR | libc::S_IRUSR));
-        file.set_permissions(perm).expect("Failed to set permissions for a key file.");
+        #[cfg(platform = "unix")]
+        {
+            use std::os::unix::fs::PermissionsExt;
+            let perm = std::fs::Permissions::from_mode(u32::from(libc::S_IWUSR | libc::S_IRUSR));
+            file.set_permissions(perm).expect("Failed to set permissions for a key file.");
+        }
         let str = serde_json::to_string_pretty(self).expect("Error serializing the key file.");
         if let Err(err) = file.write_all(str.as_bytes()) {
             panic!("Failed to write a key file {}", err);
